# Arcade ImGui

[The Python Arcade Library](https://arcade.academy/) + [pyimgui](https://github.com/swistakm/pyimgui) = :heart:

## Install

Clone the repository

        pip install git+https://github.com/kfields/arcade-imgui.git
        

## Run

Full Demo

        python example_arcade.py

Number Input Test

        python example_arcade_input.py
